aboutsummaryrefslogtreecommitdiff
path: root/src/modules/m_sajoin.cpp
diff options
context:
space:
mode:
authorGravatar Sadie Powell2020-10-26 23:40:24 +0000
committerGravatar Sadie Powell2020-10-27 00:59:11 +0000
commit7cb27dabe695505d2eb7b942c4fbf518dda8e6b3 (patch)
tree12f7541d3389efa9a084d2a4859d6ce4ede43b03 /src/modules/m_sajoin.cpp
parentReplace the check for eventfd() with a C++17 header check. (diff)
Convert CmdResult to an 8-bit strongly typed enum.
Diffstat (limited to 'src/modules/m_sajoin.cpp')
-rw-r--r--src/modules/m_sajoin.cpp20
1 files changed, 10 insertions, 10 deletions
diff --git a/src/modules/m_sajoin.cpp b/src/modules/m_sajoin.cpp
index f79c82592..012938a47 100644
--- a/src/modules/m_sajoin.cpp
+++ b/src/modules/m_sajoin.cpp
@@ -44,7 +44,7 @@ class CommandSajoin : public Command
{
const unsigned int channelindex = (parameters.size() > 1) ? 1 : 0;
if (CommandParser::LoopCall(user, this, parameters, channelindex))
- return CMD_FAILURE;
+ return CmdResult::FAILURE;
const std::string& channel = parameters[channelindex];
const std::string& nickname = parameters.size() > 1 ? parameters[0] : user->nick;
@@ -55,30 +55,30 @@ class CommandSajoin : public Command
if (user != dest && !user->HasPrivPermission("users/sajoin-others"))
{
user->WriteNotice("*** You are not allowed to /SAJOIN other users (the privilege users/sajoin-others is needed to /SAJOIN others).");
- return CMD_FAILURE;
+ return CmdResult::FAILURE;
}
if (dest->server->IsULine())
{
user->WriteNumeric(ERR_NOPRIVILEGES, "Cannot use an SA command on a U-lined client");
- return CMD_FAILURE;
+ return CmdResult::FAILURE;
}
if (IS_LOCAL(user) && !ServerInstance->IsChannel(channel))
{
/* we didn't need to check this for each character ;) */
user->WriteNotice("*** Invalid characters in channel name or name too long");
- return CMD_FAILURE;
+ return CmdResult::FAILURE;
}
Channel* chan = ServerInstance->FindChan(channel);
if ((chan) && (chan->HasUser(dest)))
{
user->WriteRemoteNotice("*** " + dest->nick + " is already on " + channel);
- return CMD_FAILURE;
+ return CmdResult::FAILURE;
}
/* For local users, we call Channel::JoinUser which may create a channel and set its TS.
* For non-local users, we just return CMD_SUCCESS, knowing this will propagate it where it needs to be
* and then that server will handle the command.
*/
LocalUser* localuser = IS_LOCAL(dest);
@@ -88,23 +88,23 @@ class CommandSajoin : public Command
if (chan)
{
ServerInstance->SNO.WriteGlobalSno('a', user->nick+" used SAJOIN to make "+dest->nick+" join "+channel);
- return CMD_SUCCESS;
+ return CmdResult::SUCCESS;
}
else
{
user->WriteNotice("*** Could not join "+dest->nick+" to "+channel);
- return CMD_FAILURE;
+ return CmdResult::FAILURE;
}
}
else
{
- return CMD_SUCCESS;
+ return CmdResult::SUCCESS;
}
}
else
{
user->WriteNotice("*** No such nickname: '" + nickname + "'");
- return CMD_FAILURE;
+ return CmdResult::FAILURE;
}
}
@@ -55,30 +55,30 @@ class CommandSajoin : public Command
}
/* For local users, we call Channel::JoinUser which may create a channel and set its TS.
- * For non-local users, we just return CMD_SUCCESS, knowing this will propagate it where it needs to be
+ * For non-local users, we just return CmdResult::SUCCESS, knowing this will propagate it where it needs to be
* and then that server will handle the command.
*/